@@ -358,7 +358,7 @@ class BGLDataset(LogDataset):
             # self.
             self.anomalous_logs = list(self.logs[self.logs['Label'] != '-']['event_id'].unique())
             self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
-            self.logs['timestamp'] = pd.to_datetime(self.logs['timestamp'])
+            self.logs['timestamp'] = pd.to_datetime(self.logs['timestamp'], format="%Y-%m-%d-%H.%M.%S.%f")
             self.logs = self.logs[['timestamp', 'event_id']]
             print ("Short processed file is loaded up. Have fun.")
 
